# SSH Agent


## Implementations

| Component         | Link                                                                                                               |
|-------------------|--------------------------------------------------------------------------------------------------------------------|
| client            | [xpra.client.subsystem.ssh_agent](https://github.com/Xpra-org/xpra/blob/master/xpra/client/subsystem/ssh_agent.py) |
| client connection | n/a                                                                                                                |
| server            | [xpra.server.subsystem.ssh_agent](https://github.com/Xpra-org/xpra/blob/master/xpra/server/subsystem/ssh_agent.py)           |


## Capabilities

TBD

## Network Packets

TBD